@@ -64,9 +64,12 @@ class Model(torch.nn.Module):
 
         batch_shapes = [ [batch_size]+list(i) for i in input_shape]
         probe_inputs = [torch.zeros(size=sz).to(dtype=dt, device=device) for sz,dt in zip(batch_shapes, dtype)]
-        self.model(*probe_inputs)
 
-        self._probe_inputs = probe_inputs
+        _training_state = self.model.training
+        self.model.eval()(*probe_inputs)
+        self.model.train(_training_state)
+
+        self._probe_inputs = [i.cpu() for i in probe_inputs]
         self.built = True
         return self
 
@@ -83,9 +86,10 @@ class Model(torch.nn.Module):
         if device is None:
             device = self.trainer.device if self.compiled else 'cpu'
         
-        summary(self.model, self._probe_inputs, depth=depth, verbose=1, device=device)
+        probe_inputs = [i.to(device=device) for i in self._probe_inputs]
+        summary(self.model, probe_inputs, depth=depth, verbose=1, device=device)
 
-    def compile(self, optimizer, loss, metrics=None, epoch_metrics=None, device=None, loop_config=None):
+    def compile(self, optimizer, loss, metrics=None, epoch_metrics=None, device=None, loop_config=None, disable_val_loss=False):
         """
         Configure the model for training.
 
@@ -117,7 +121,7 @@ class Model(torch.nn.Module):
         epoch_metrics = _to_metrics_dic(epoch_metrics)
 
         self.to(device=device)
-        self.trainer = Trainer(model=self, optimizer=optimizer, loss=loss, metrics=batch_metrics, epoch_metrics=epoch_metrics, device=device, loop_config=loop_config)
+        self.trainer = Trainer(model=self, optimizer=optimizer, loss=loss, metrics=batch_metrics, epoch_metrics=epoch_metrics, device=device, loop_config=loop_config, disable_val_loss=disable_val_loss)
         self.compiled = True
 
 
@@ -258,7 +262,7 @@ class Model(torch.nn.Module):
         return dict(self.trainer.valid_on_epoch(data_loader, use_amp))
 
     @torch.no_grad()
-    def predict_dl(self, data_loader, device=None, output_numpy=True, activation=None, use_amp=False):
+    def predict_dl(self, data_loader, device=None, output_numpy=True, activation=None, use_amp=False, progress_bar=False):
         self._check_keras_layer()
 
         if device is None:
@@ -269,8 +273,15 @@ class Model(torch.nn.Module):
         self.eval().to(device=device)
         
         activation = _create_activation(activation)
+        if activation is None:
+            activation = lambda x: x
 
         outputs = []
+
+        if progress_bar:
+            from tqdm import tqdm
+            data_loader = tqdm(data_loader)
+
         for batch in data_loader:
             if not isinstance(batch, list):
                 batch = [batch]
@@ -280,17 +291,15 @@ class Model(torch.nn.Module):
 
             with autocast(use_amp, device):
                 o = self(*batch)
+                o = activation(o)
                 outputs.append(o)
 
-        outputs = torch.cat(outputs, dim=0).float()
-
-        if activation is not None:
-            outputs = activation(outputs)
+        outputs = torch.cat(outputs, dim=0)
 
         return outputs.cpu().numpy() if output_numpy else outputs
 
     @torch.no_grad()
-    def predict(self, x, batch_size=32, device=None, output_numpy=True, activation=None, num_workers=0, use_amp=False, **dl_kwargs):
+    def predict(self, x, batch_size=32, device=None, output_numpy=True, activation=None, num_workers=0, use_amp=False, progress_bar=False, **dl_kwargs):
         """Generate output predictions for the input samples.\n\n    Computation is done in batches."""
         if isinstance(x, Dataset):
             test_set = x
@@ -299,7 +308,7 @@ class Model(torch.nn.Module):
                 x = [x]
             test_set = TensorDataset(*to_tensor(x))
         data_loader = DataLoader(test_set, batch_size=batch_size, shuffle=False, num_workers=_get_num_workers(num_workers), **dl_kwargs)
-        return self.predict_dl(data_loader, device=device, output_numpy=output_numpy, activation=activation, use_amp=use_amp)
+        return self.predict_dl(data_loader, device=device, output_numpy=output_numpy, activation=activation, use_amp=use_amp, progress_bar=progress_bar)
 
     def save_weights(self, filepath):
         """Equal to `torch.save(model.state_dict(), filepath)`."""
